
2023 NOV 13

*   Implement DAG of plugin dependencies.
*   Implement FS_26_43_73_72 func tree with automatic func `data_envelope` loading and searching.
*   Make FS_01_89_09_24 interp tree work similarly to func tree.
*   Implement FS_91_88_07_23 jump tree to override tree path.
*   Implement FS_43_50_57_71 `echo_args` func.
